.. Trazer documentation master file, created by
   sphinx-quickstart on Sat May 15 13:38:25 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. mdinclude:: ../../README.md

.. toctree::
   :maxdepth: 2

   trazer


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
